@@ -22,21 +22,20 @@
 filter_precedence <- function(eventlog,
 							  antecedents,
 							  consequents,
-							  precedence_type,
-							  filter_method,
+							  precedence_type = c("directly_follows", "eventually_follows"),
+							  filter_method = c("each","one_of"),
 							  reverse = F) {
 	stop_eventlog(eventlog)
 
-	if(!(precedence_type %in% c("directly_follows","eventually_follows")))
-		stop("Precedence type should be one of the following: directly_follows, eventually_follows")
+	precedence_type <- match.arg(precedence_type)
+	filter_method <- match.arg(filter_method)
+
+
 	if(precedence_type == "directly_follows")
 		interleavings_allowed = FALSE
 	else
 		interleavings_allowed = TRUE
 
-	if(!(filter_method %in% c("each","one_of")))
-		stop("filter_method should be one of the following: each, one_of")
-
 	sequences <- paste(rep(antecedents, each = length(consequents)),
 					   rep(consequents, times = length(antecedents)), sep = ",")
 	number_of_conditions <- length(sequences)
@@ -66,7 +65,53 @@ filter_precedence <- function(eventlog,
 					   case_id = case_id(eventlog),
 					   timestamp =timestamp(eventlog),
 					   lifecycle_id = lifecycle_id(eventlog),
-					   activity_instance_id = activity_instance_id(eventlog))
+					   activity_instance_id = activity_instance_id(eventlog),
+					   resource_id = resource_id(eventlog))
 	return(output)
 
 }
+
+#' @rdname filter_precedence
+#' @export ifilter_precedence
+#'
+ifilter_precedence <- function(eventlog) {
+
+ui <- miniPage(
+	gadgetTitleBar("Filter on precedences"),
+	miniContentPanel(
+		fillCol(flex = c(5,3,2),
+			fillRow(flex = c(10,1,10),
+				selectizeInput("ante", label = "Select antecedents:",
+							   choices = eventlog %>% pull(!!as.symbol(activity_id(eventlog))) %>%
+							   	unique, selected = NA,  multiple = T), " ",
+				selectizeInput("conse", label = "Select consequents:",
+							   choices = eventlog %>% pull(!!as.symbol(activity_id(eventlog))) %>%
+							   	unique, selected = NA,  multiple = T)),
+				fillRow(
+				radioButtons("type", "Precedence filter: ", choices = c("Directly follows" = "directly_follows", "Eventually follows"="eventually_follows"), selected = "directly_follows"),
+				radioButtons("method", "Reverse filter: ", choices = c("Each" = "each", "One of" = "one_of"), selected = "each"),
+				radioButtons("reverse", "Reverse filter: ", choices = c("Yes","No"), selected = "No")),
+				"When directly_follows, the consequent activity should happen immediately after the antecedent activities. When eventually_follows, other events are allowed to happen in between. When each, only cases where all the relations are valid are preserved. When one_of, all the cases where at least one of the conditions hold are preserved."
+			)
+
+	)
+)
+
+server <- function(input, output, session){
+	observeEvent(input$done, {
+
+		filtered_log <- filter_precedence(eventlog,
+										  antecedents = input$ante,
+										  consequents = input$conse,
+										  precedence_type = input$type,
+										  filter_method = input$method,
+										  reverse = ifelse(input$reverse == "Yes", T, F))
+
+
+		stopApp(filtered_log)
+	})
+}
+runGadget(ui, server, viewer = dialogViewer("Filter on precedences", height = 400))
+
+}
+
