@@ -8,11 +8,11 @@ filter_trace_frequency_percentile <- function(eventlog,
 
 	if(reverse == F)
 		case_selection <- merge(cases_light(eventlog),
-								trace_frequency(eventlog) %>%
+								trace_coverage(eventlog, "trace") %>%
 									filter(cum_sum <= percentile_cut_off))
 	else
 		case_selection <- merge(cases_light(eventlog),
-								trace_frequency(eventlog) %>%
+								trace_coverage(eventlog, "trace") %>%
 									filter(cum_sum > percentile_cut_off))
 
 
