@@ -13,7 +13,12 @@ redo_selfloops_referral_matrix <- function(eventlog) {
 	eventlog %>%
 		redo_selfloops() %>%
 		group_by(first_resource, last_resource) %>%
-		summarize(absolute = n()) %>%
-		return()
+		summarize(absolute = n()) -> output
+
+	class(output) <- c("referral_matrix", class(output))
+	attr(output, "type") <- "selfloop"
+	attr(output, "mapping") <- mapping(eventlog)
+
+	return(output)
 }
 
